@@ -1,4 +1,4 @@
-from .families import preprocess_families, ProcessedFamily
+from .families import preprocess_families
 from .io import ped2graph
 from .likelihood import compute_family_likelihood
 from .estimate import estimate_rates
\ No newline at end of file
